Reactor.Error.Invalid.UndoStepError exception (reactor v1.0.0)
View SourceThis error is returned when an error occurs when attempting to undo step execution.
Its error key will contain the error that was raised or returned by the
c:Step.undo/4 callback.
Summary
Functions
Create an Elixir.Reactor.Error.Invalid.UndoStepError without raising it.
Functions
@spec exception(opts :: Keyword.t()) :: %Reactor.Error.Invalid.UndoStepError{ __exception__: true, bread_crumbs: term(), class: term(), error: term(), path: term(), splode: term(), stacktrace: term(), step: term(), vars: term() }
Create an Elixir.Reactor.Error.Invalid.UndoStepError without raising it.
Keys
- :step
- :error