Reactor.Step.Compose
(reactor v1.0.1)
A built-in step which can embed one reactor inside another.
This step calls Reactor.run/3 on the inner reactor and returns it's result.
Reactor will correctly share the concurrency availability over both the parent
and child Reactors.